@@ -1,26 +1,14 @@
 /* This file is part of Kleopatra
 
-   Copyright (c) 2016 Intevation GmbH
+   SPDX-FileCopyrightText: 2016 Intevation GmbH
 
    It is based on libkdbus kdbusservicetest which is:
 
-   Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
-   Copyright (c) 2011 David Faure <faure@kde.org>
-   Copyright (c) 2011 Kevin Ottens <ervin@kde.org>
+   SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+   SPDX-FileCopyrightText: 2011 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2011 Kevin Ottens <ervin@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 /* The main modification in this test is that every activateRequested
