@@ -2,32 +2,9 @@
     aboutdata.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2001,2002,2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2001, 2002, 2004 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -35,6 +12,8 @@
 
 #include "aboutdata.h"
 
+#include <Libkleo/GnuPG>
+
 #include <KLocalizedString>
 
 static const char kleopatra_version[] = KLEOPATRA_VERSION_STRING;
@@ -89,12 +68,19 @@ static const about_data credits[] = {
 
 AboutData::AboutData()
     : KAboutData(QStringLiteral("kleopatra"), i18n("Kleopatra"),
-                 QLatin1String(kleopatra_version), i18n(description), KAboutLicense::GPL,
+#ifdef Q_OS_WIN
+                 Kleo::gpg4winVersion(),
+                 Kleo::gpg4winDescription(),
+#else
+                 QLatin1String(kleopatra_version),
+                 i18n(description),
+#endif
+                 KAboutLicense::GPL,
                  i18n("(c) 2002 Steffen\u00A0Hansen, Matthias\u00A0Kalle\u00A0" "Dalheimer, Klar\u00E4lvdalens\u00A0" "Datakonsult\u00A0" "AB\n"
                       "(c) 2004, 2007, 2008, 2009 Marc\u00A0Mutz, Klar\u00E4lvdalens\u00A0" "Datakonsult\u00A0" "AB") +
-                 QLatin1Char('\n') + i18n("(c) 2010-2019 The Kleopatra developers")
+                 QLatin1Char('\n') + i18n("(c) 2010-2020 The Kleopatra developers, g10 Code GmbH, Intevation GmbH")
 #ifdef Q_OS_WIN
-                 , i18n("<a href=https://www.gpg4win.org>Visit the Gpg4win homepage</a>")
+                 , Kleo::gpg4winLongDescription()
 #endif
                  )
 {
