@@ -2,32 +2,9 @@
     commands/command.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -58,16 +35,27 @@ using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace GpgME;
 
+Command::Private::Private(Command *qq)
+    : q(qq),
+      autoDelete(true),
+      warnWhenRunningAtShutdown(true)
+{
+}
+
 Command::Private::Private(Command *qq, KeyListController *controller)
     : q(qq),
       autoDelete(true),
       warnWhenRunningAtShutdown(true),
-      indexes_(),
-      view_(),
-      parentWId(0),
       controller_(controller)
 {
+}
 
+Command::Private::Private(Command *qq, QWidget *parent)
+    : q(qq),
+      autoDelete(true),
+      warnWhenRunningAtShutdown(true),
+      parentWidget_(parent)
+{
 }
 
 Command::Private::~Private()
@@ -114,13 +102,13 @@ Command::Command(QAbstractItemView *v, Private *pp)
 }
 
 Command::Command(const GpgME::Key &key)
-    : QObject(nullptr), d(new Private(this, nullptr))
+    : QObject(nullptr), d(new Private(this))
 {
     d->keys_ = std::vector<Key>(1, key);
 }
 
 Command::Command(const std::vector<GpgME::Key> &keys)
-    : QObject(nullptr), d(new Private(this, nullptr))
+    : QObject(nullptr), d(new Private(this))
 {
     d->keys_ = keys;
 }
