@@ -2,32 +2,9 @@
     systemtrayicon.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -98,17 +75,19 @@ private:
         //triggering slotEnableDisableActions again
         const QSignalBlocker blocker(QApplication::clipboard());
         openCertificateManagerAction.setEnabled(!q->mainWindow() || !q->mainWindow()->isVisible());
-        setInitialPinAction.setEnabled(anyCardHasNullPin);
+        setInitialPinAction.setEnabled(!firstCardWithNullPin.empty());
         learnCertificatesAction.setEnabled(anyCardCanLearnKeys);
 
-        q->setAttentionWanted((anyCardHasNullPin || anyCardCanLearnKeys) && !q->attentionWindow());
+        q->setAttentionWanted((!firstCardWithNullPin.empty() || anyCardCanLearnKeys) && !q->attentionWindow());
     }
 
     void slotSetInitialPin()
     {
-        SetInitialPinCommand *cmd = new SetInitialPinCommand;
-        q->setAttentionWindow(cmd->dialog());
-        startCommand(cmd);
+        if (!firstCardWithNullPin.empty()) {
+            SetInitialPinCommand *cmd = new SetInitialPinCommand(firstCardWithNullPin);
+            q->setAttentionWindow(cmd->dialog());
+            startCommand(cmd);
+        }
     }
 
     void slotLearnCertificates()
@@ -125,9 +104,9 @@ private:
     }
 
 private:
-    bool anyCardHasNullPin;
-    bool anyCardCanLearnKeys;
-    bool learningInProgress;
+    std::string firstCardWithNullPin;
+    bool anyCardCanLearnKeys = false;
+    bool learningInProgress = false;
 
     QMenu menu;
     QAction openCertificateManagerAction;
@@ -148,8 +127,6 @@ private:
 
 SysTrayIcon::Private::Private(SysTrayIcon *qq)
     : q(qq),
-      anyCardHasNullPin(false),
-      anyCardCanLearnKeys(false),
       menu(),
       openCertificateManagerAction(i18n("&Open Certificate Manager..."), q),
       configureAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure %1...", KAboutData::applicationData().componentName()), q),
@@ -231,7 +208,7 @@ void SysTrayIcon::doActivated()
         if (aw->isVisible()) {
             return;    // ignore clicks while an attention window is open.
         }
-    if (d->anyCardHasNullPin) {
+    if (!d->firstCardWithNullPin.empty()) {
         d->slotSetInitialPin();
     } else if (d->anyCardCanLearnKeys) {
         d->slotLearnCertificates();
@@ -241,12 +218,12 @@ void SysTrayIcon::doActivated()
     }
 }
 
-void SysTrayIcon::setAnyCardHasNullPin(bool on)
+void SysTrayIcon::setFirstCardWithNullPin(const std::string &serialNumber)
 {
-    if (d->anyCardHasNullPin == on) {
+    if (d->firstCardWithNullPin == serialNumber) {
         return;
     }
-    d->anyCardHasNullPin = on;
+    d->firstCardWithNullPin = serialNumber;
     slotEnableDisableActions();
 }
 
