@@ -1,32 +1,9 @@
 /*  view/netkeywidget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 Intevation GmbH
+    SPDX-FileCopyrightText: 2017 Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "netkeywidget.h"
 #include "nullpinwidget.h"
@@ -59,7 +36,7 @@ using namespace Kleo::Commands;
 
 NetKeyWidget::NetKeyWidget(QWidget *parent) :
     QWidget(parent),
-    mSerialNumber(new QLabel(this)),
+    mSerialNumberLabel(new QLabel(this)),
     mVersionLabel(new QLabel(this)),
     mLearnKeysLabel(new QLabel(this)),
     mErrorLabel(new QLabel(this)),
@@ -79,17 +56,18 @@ NetKeyWidget::NetKeyWidget(QWidget *parent) :
     mAreaWidget->setLayout(vLay);
     mArea->setWidget(mAreaWidget);
     auto scrollLay = new QVBoxLayout(this);
+    scrollLay->setContentsMargins(0, 0, 0, 0);
     scrollLay->addWidget(mArea);
 
     // Add general widgets
     mVersionLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     vLay->addWidget(mVersionLabel, 0, Qt::AlignLeft);
 
-    mSerialNumber->setTextInteractionFlags(Qt::TextBrowserInteraction);
+    mSerialNumberLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
 
     auto hLay1 = new QHBoxLayout;
     hLay1->addWidget(new QLabel(i18n("Serial number:")));
-    hLay1->addWidget(mSerialNumber);
+    hLay1->addWidget(mSerialNumberLabel);
     hLay1->addStretch(1);
     vLay->addLayout(hLay1);
 
@@ -179,9 +157,11 @@ NetKeyWidget::~NetKeyWidget()
 
 void NetKeyWidget::setCard(const NetKeyCard* card)
 {
+    mSerialNumber = card->serialNumber();
     mVersionLabel->setText(i18nc("1 is a Version number", "NetKey v%1 Card", card->appVersion()));
-    mSerialNumber->setText(QString::fromStdString(card->serialNumber()));
+    mSerialNumberLabel->setText(QString::fromStdString(mSerialNumber));
 
+    mNullPinWidget->setSerialNumber(mSerialNumber);
     /* According to users of NetKey Cards it is fairly uncommon
      * to use SigG Certificates at all. So it should be optional to set the pins. */
     mNullPinWidget->setVisible(card->hasNKSNullPin() /*|| card->hasSigGNullPin()*/);
@@ -241,13 +221,17 @@ void NetKeyWidget::setNksPinSettingResult(const GpgME::Error &err)
 
 void NetKeyWidget::doChangePin(bool sigG)
 {
+    const auto nksCard = ReaderStatus::instance()->getCard<NetKeyCard>(mSerialNumber);
+    if (!nksCard) {
+        KMessageBox::error(this, i18n("Failed to find the NetKey card with the serial number: %1", QString::fromStdString(mSerialNumber)));
+        return;
+    }
+
     if (sigG) {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD PW1.CH.SIG",
-                                 this, "setSigGPinSettingResult");
+        ReaderStatus::mutableInstance()->startSimpleTransaction(
+            nksCard, "SCD PASSWD PW1.CH.SIG", this, "setSigGPinSettingResult");
     } else {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD PW1.CH",
-                                 this, "setNksPinSettingResult");
+        ReaderStatus::mutableInstance()->startSimpleTransaction(
+            nksCard, "SCD PASSWD PW1.CH", this, "setNksPinSettingResult");
     }
 }
