@@ -1,44 +1,23 @@
 /*  view/pgpcardwiget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 by Bundesamt für Sicherheit in der Informationstechnik
-    Software engineering by Intevation GmbH
+    SPDX-FileCopyrightText: 2017 Bundesamt für Sicherheit in der Informationstechnik
+    SPDX-FileContributor: Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "pgpcardwidget.h"
 
 #include "kleopatra_debug.h"
 
+#include "commands/changepincommand.h"
+
 #include "smartcard/openpgpcard.h"
 #include "smartcard/readerstatus.h"
 
 #include "dialogs/gencardkeydialog.h"
-#include "utils/gnupg-helper.h"
+#include <Libkleo/GnuPG>
 
 #include <QProgressDialog>
 #include <QThread>
@@ -67,6 +46,7 @@
 #include <gpgme++/gpggencardkeyinteractor.h>
 
 using namespace Kleo;
+using namespace Kleo::Commands;
 using namespace Kleo::SmartCard;
 
 namespace {
@@ -93,7 +73,8 @@ class GenKeyThread: public QThread
     protected:
         void run() override {
             GpgME::GpgGenCardKeyInteractor *ei = new GpgME::GpgGenCardKeyInteractor(mSerial);
-            ei->setKeySize(mParams.keysize);
+            ei->setAlgo(GpgME::GpgGenCardKeyInteractor::RSA);
+            ei->setKeySize(QByteArray::fromStdString(mParams.algorithm).toInt());
             ei->setNameUtf8(mParams.name.toStdString());
             ei->setEmailUtf8(mParams.email.toStdString());
             ei->setDoBackup(mParams.backup);
@@ -139,6 +120,7 @@ PGPCardWidget::PGPCardWidget(QWidget *parent):
     areaVLay->addStretch(1);
     area->setWidget(areaWidget);
     auto myLayout = new QVBoxLayout(this);
+    myLayout->setContentsMargins(0, 0, 0, 0);
     myLayout->addWidget(area);
 
     // Version and Serialnumber
@@ -207,17 +189,17 @@ PGPCardWidget::PGPCardWidget(QWidget *parent):
     auto pinButtton = new QPushButton(i18n("Change PIN"));
     pinButtton->setToolTip(i18n("Change the PIN required to unblock the smartcard."));
     actionLayout->addWidget(pinButtton);
-    connect(pinButtton, &QPushButton::clicked, this, [this] () {doChangePin(1);});
+    connect(pinButtton, &QPushButton::clicked, this, [this] () { doChangePin(OpenPGPCard::pinKeyRef()); });
 
     auto pukButton = new QPushButton(i18n("Change Admin PIN"));
     pukButton->setToolTip(i18n("Change the PIN required to unlock the smartcard."));
     actionLayout->addWidget(pukButton);
-    connect(pukButton, &QPushButton::clicked, this, [this] () {doChangePin(3);});
+    connect(pukButton, &QPushButton::clicked, this, [this] () { doChangePin(OpenPGPCard::adminPinKeyRef()); });
 
     auto resetCodeButton = new QPushButton(i18n("Change Reset Code"));
     pukButton->setToolTip(i18n("Change the PIN required to reset the smartcard to an empty state."));
     actionLayout->addWidget(resetCodeButton);
-    connect(resetCodeButton, &QPushButton::clicked, this, [this] () {doChangePin(2);});
+    connect(resetCodeButton, &QPushButton::clicked, this, [this] () { doChangePin(OpenPGPCard::resetCodeKeyRef()); });
 
     actionLayout->addStretch(-1);
     grid->addLayout(actionLayout, row++, 0, 1, 4);
@@ -227,17 +209,19 @@ PGPCardWidget::PGPCardWidget(QWidget *parent):
 
 void PGPCardWidget::setCard(const OpenPGPCard *card)
 {
-    const QString version = QString::fromStdString(card->cardVersion());
+    const QString version = card->displayAppVersion();
 
-    mIs21 = versionIsAtLeast("2.1", card->cardVersion().c_str());
-    mVersionLabel->setText(i18nc("First placeholder is manufacturer, second placeholder is a version number",
-                                 "%1 OpenPGP v%2 card", QString::fromStdString(card->manufacturer()),
-                                 version));
-    const QString sn = QString::fromStdString(card->serialNumber()).mid(16, 12);
-    mSerialNumber->setText(sn);
+    mIs21 = card->appVersion() >= 0x0201;
+    const QString manufacturer = QString::fromStdString(card->manufacturer());
+    const bool manufacturerIsUnknown = manufacturer.isEmpty() || manufacturer == QLatin1String("unknown");
+    mVersionLabel->setText(manufacturerIsUnknown ?
+        i18nc("Placeholder is a version number", "Unknown OpenPGP v%1 card", version) :
+        i18nc("First placeholder is manufacturer, second placeholder is a version number",
+              "%1 OpenPGP v%2 card", manufacturer, version));
+    mSerialNumber->setText(card->displaySerialNumber());
     mRealSerial = card->serialNumber();
 
-    const auto holder = QString::fromStdString(card->cardHolder());
+    const auto holder = card->cardHolder();
     const auto url = QString::fromStdString(card->pubkeyUrl());
     mCardHolderLabel->setText(holder.isEmpty() ? i18n("not set") : holder);
     mUrl = url;
@@ -251,15 +235,39 @@ void PGPCardWidget::setCard(const OpenPGPCard *card)
     mCardIsEmpty = card->authFpr().empty() && card->sigFpr().empty() && card->encFpr().empty();
 }
 
-void PGPCardWidget::doChangePin(int slot)
+void PGPCardWidget::doChangePin(const std::string &keyRef)
 {
-    ReaderStatus::mutableInstance()
-    ->startSimpleTransaction(QStringLiteral("SCD PASSWD %1").arg(slot).toUtf8().constData(),
-                             this, "changePinResult");
+    auto cmd = new ChangePinCommand(mRealSerial, OpenPGPCard::AppName, this);
+    this->setEnabled(false);
+    connect(cmd, &ChangePinCommand::finished,
+            this, [this]() {
+                this->setEnabled(true);
+            });
+    cmd->setKeyRef(keyRef);
+    cmd->start();
 }
 
 void PGPCardWidget::doGenKey(GenCardKeyDialog *dlg)
 {
+    if (!(engineInfo(GpgME::GpgEngine).engineVersion() < "2.3.0")) {
+        GpgME::Error err;
+        std::unique_ptr<GpgME::Context> c = GpgME::Context::createForEngine(GpgME::AssuanEngine, &err);
+        if (err.code() == GPG_ERR_NOT_SUPPORTED) {
+            return;
+        }
+        auto assuanContext = std::shared_ptr<GpgME::Context>(c.release());
+        const auto serialNumber = ReaderStatus::switchCard(assuanContext, mRealSerial, err);
+        if (err || serialNumber != mRealSerial) {
+            qCWarning(KLEOPATRA_LOG) << "Switching to card" << QString::fromStdString(mRealSerial) << "failed";
+            return;
+        }
+        const auto appName = ReaderStatus::switchApp(assuanContext, mRealSerial, OpenPGPCard::AppName, err);
+        if (err || appName != OpenPGPCard::AppName) {
+            qCWarning(KLEOPATRA_LOG) << "Switching card to" << QString::fromStdString(OpenPGPCard::AppName) << "app failed";
+            return;
+        }
+    }
+
     const auto params = dlg->getKeyParams();
 
     auto progress = new QProgressDialog(this, Qt::CustomizeWindowHint | Qt::WindowTitleHint | Qt::Dialog);
@@ -330,16 +338,17 @@ void PGPCardWidget::genkeyRequested()
         }
     }
 
-    GenCardKeyDialog *dlg = new GenCardKeyDialog(this);
-    std::vector <int> sizes;
-    sizes.push_back(1024);
-    sizes.push_back(2048);
-    sizes.push_back(3072);
+    GenCardKeyDialog *dlg = new GenCardKeyDialog(GenCardKeyDialog::AllKeyAttributes, this);
+    std::vector<std::pair<std::string, QString>> algos = {
+        { "1024", QStringLiteral("RSA 1024") },
+        { "2048", QStringLiteral("RSA 2048") },
+        { "3072", QStringLiteral("RSA 3072") }
+    };
     // There is probably a better way to check for capabilities
     if (mIs21) {
-        sizes.push_back(4096);
+        algos.push_back({"4096", QStringLiteral("RSA 4096")});
     }
-    dlg->setSupportedSizes(sizes);
+    dlg->setSupportedAlgorithms(algos, "2048");
     connect(dlg, &QDialog::accepted, this, [this, dlg] () {
             doGenKey(dlg);
             dlg->deleteLater();
@@ -348,21 +357,6 @@ void PGPCardWidget::genkeyRequested()
     dlg->show();
 }
 
-void PGPCardWidget::changePinResult(const GpgME::Error &err)
-{
-    if (err) {
-        KMessageBox::error(this, i18nc("@info",
-                           "PIN change failed: %1", QString::fromLatin1(err.asString())),
-                           i18nc("@title", "Error"));
-        return;
-    }
-    if (!err.isCanceled()) {
-        KMessageBox::information(this, i18nc("@info",
-                    "Code successfully changed."),
-                i18nc("@title", "Success"));
-    }
-}
-
 void PGPCardWidget::changeNameRequested()
 {
     QString text = mCardHolderLabel->text();
@@ -399,9 +393,14 @@ void PGPCardWidget::changeNameRequested()
     const auto lastName = parts.takeLast();
     const QString formatted = lastName + QStringLiteral("<<") + parts.join(QLatin1Char('<'));
 
-    ReaderStatus::mutableInstance()
-    ->startSimpleTransaction(QStringLiteral("SCD SETATTR DISP-NAME %1").arg(formatted).toUtf8().constData(),
-                             this, "changeNameResult");
+    const auto pgpCard = ReaderStatus::instance()->getCard<OpenPGPCard>(mRealSerial);
+    if (!pgpCard) {
+        KMessageBox::error(this, i18n("Failed to find the OpenPGP card with the serial number: %1", QString::fromStdString(mRealSerial)));
+        return;
+    }
+
+    const QByteArray command = QByteArrayLiteral("SCD SETATTR DISP-NAME ") + formatted.toUtf8();
+    ReaderStatus::mutableInstance()->startSimpleTransaction(pgpCard, command, this, "changeNameResult");
 }
 
 void PGPCardWidget::changeNameResult(const GpgME::Error &err)
@@ -441,9 +440,14 @@ void PGPCardWidget::changeUrlRequested()
         break;
     }
 
-    ReaderStatus::mutableInstance()
-    ->startSimpleTransaction(QStringLiteral("SCD SETATTR PUBKEY-URL %1").arg(text).toUtf8().constData(),
-                             this, "changeUrlResult");
+    const auto pgpCard = ReaderStatus::instance()->getCard<OpenPGPCard>(mRealSerial);
+    if (!pgpCard) {
+        KMessageBox::error(this, i18n("Failed to find the OpenPGP card with the serial number: %1", QString::fromStdString(mRealSerial)));
+        return;
+    }
+
+    const QByteArray command = QByteArrayLiteral("SCD SETATTR PUBKEY-URL ") + text.toUtf8();
+    ReaderStatus::mutableInstance()->startSimpleTransaction(pgpCard, command, this, "changeUrlResult");
 }
 
 void PGPCardWidget::changeUrlResult(const GpgME::Error &err)
